@@ -1,32 +1,35 @@
 var group__pw__resource =
 [
+    [ "resource.h", "resource_8h.html", null ],
     [ "pw_resource_events", "structpw__resource__events.html", [
+      [ "version", "structpw__resource__events.html#a41e29d4a60ff80ff183c2cb56060f7e9", null ],
       [ "destroy", "structpw__resource__events.html#a0472df3f84251f7c7f5a36692bd0ac6e", null ],
-      [ "error", "structpw__resource__events.html#af8ab8db63d0b4e3a332ff552e416e5a2", null ],
       [ "pong", "structpw__resource__events.html#a0a276ed65fe8f88887e9fbd0d08df018", null ],
-      [ "version", "structpw__resource__events.html#a41e29d4a60ff80ff183c2cb56060f7e9", null ]
+      [ "error", "structpw__resource__events.html#af8ab8db63d0b4e3a332ff552e416e5a2", null ]
     ] ],
+    [ "pw_resource", "structpw__resource.html", null ],
+    [ "PW_VERSION_RESOURCE_EVENTS", "group__pw__resource.html#gaadff480a3e38ec195e07567c1e46ab54", null ],
+    [ "pw_resource_notify", "group__pw__resource.html#ga400f8bdb7b5779db732e3f224b87e07e", null ],
     [ "pw_resource_call", "group__pw__resource.html#ga61e286d92a2f528ebe48cb1436ac4eba", null ],
     [ "pw_resource_call_res", "group__pw__resource.html#ga11df048744c827fbefc328ec7b9dc135", null ],
-    [ "pw_resource_notify", "group__pw__resource.html#ga400f8bdb7b5779db732e3f224b87e07e", null ],
+    [ "pw_resource_new", "group__pw__resource.html#gaeb9ac77ab0c2ad96099396c64a4ffb92", null ],
+    [ "pw_resource_destroy", "group__pw__resource.html#gab9e159d75b7efe39bd53b64055244092", null ],
+    [ "pw_resource_remove", "group__pw__resource.html#ga1774043ade001a33ab65e5fbabd5d89e", null ],
+    [ "pw_resource_get_client", "group__pw__resource.html#ga8baec43db135c6f71cf26b7b3e500361", null ],
+    [ "pw_resource_get_id", "group__pw__resource.html#gaf8fe4859dd6826d5eb6c7e28f5519215", null ],
+    [ "pw_resource_get_permissions", "group__pw__resource.html#ga332bee9e00671e80bd1d897551aa065d", null ],
+    [ "pw_resource_get_type", "group__pw__resource.html#gafc89e299d5a8ee7eb725e6b4994b61a6", null ],
+    [ "pw_resource_get_protocol", "group__pw__resource.html#ga5f5b343c88d5274a6702755a6452cb40", null ],
+    [ "pw_resource_get_user_data", "group__pw__resource.html#gafc12935cd9ee93e992cae1e2910e6f04", null ],
     [ "pw_resource_add_listener", "group__pw__resource.html#ga119a41be865f03ef8736977acba8a323", null ],
     [ "pw_resource_add_object_listener", "group__pw__resource.html#gaa2d8c1bd7008acbd8fe30e47e6c08d3f", null ],
-    [ "pw_resource_destroy", "group__pw__resource.html#gab9e159d75b7efe39bd53b64055244092", null ],
+    [ "pw_resource_ping", "group__pw__resource.html#ga9edff924e88ea8ae7d0b74065ad7415a", null ],
+    [ "pw_resource_set_bound_id", "group__pw__resource.html#gaf3044f96f645e97035b87d3b37d3e017", null ],
+    [ "pw_resource_get_bound_id", "group__pw__resource.html#ga6006f7393419cb5c874398f2954ac1b4", null ],
     [ "pw_resource_error", "group__pw__resource.html#ga98bbacb715f5469dcc14a071d14b3883", null ],
     [ "pw_resource_errorf", "group__pw__resource.html#ga69d44482d7bb5e6fbb95a66ccce009ed", null ],
     [ "pw_resource_errorf_id", "group__pw__resource.html#ga1e81134b32b4a8ab7fe861e823f5e210", null ],
-    [ "pw_resource_get_bound_id", "group__pw__resource.html#ga6006f7393419cb5c874398f2954ac1b4", null ],
-    [ "pw_resource_get_client", "group__pw__resource.html#ga8baec43db135c6f71cf26b7b3e500361", null ],
-    [ "pw_resource_get_id", "group__pw__resource.html#gaf8fe4859dd6826d5eb6c7e28f5519215", null ],
-    [ "pw_resource_get_marshal", "group__pw__resource.html#ga9135836c3f3a0860261aee85ae6dcc3c", null ],
     [ "pw_resource_get_object_listeners", "group__pw__resource.html#gae08cdf7d997595185d3e7ff0235a6305", null ],
-    [ "pw_resource_get_permissions", "group__pw__resource.html#ga332bee9e00671e80bd1d897551aa065d", null ],
-    [ "pw_resource_get_protocol", "group__pw__resource.html#ga5f5b343c88d5274a6702755a6452cb40", null ],
-    [ "pw_resource_get_type", "group__pw__resource.html#gafc89e299d5a8ee7eb725e6b4994b61a6", null ],
-    [ "pw_resource_get_user_data", "group__pw__resource.html#gafc12935cd9ee93e992cae1e2910e6f04", null ],
-    [ "pw_resource_install_marshal", "group__pw__resource.html#ga6000827e0dc8637b0538f75800c0f581", null ],
-    [ "pw_resource_new", "group__pw__resource.html#gaeb9ac77ab0c2ad96099396c64a4ffb92", null ],
-    [ "pw_resource_ping", "group__pw__resource.html#ga9edff924e88ea8ae7d0b74065ad7415a", null ],
-    [ "pw_resource_remove", "group__pw__resource.html#ga1774043ade001a33ab65e5fbabd5d89e", null ],
-    [ "pw_resource_set_bound_id", "group__pw__resource.html#gaf3044f96f645e97035b87d3b37d3e017", null ]
+    [ "pw_resource_get_marshal", "group__pw__resource.html#ga9135836c3f3a0860261aee85ae6dcc3c", null ],
+    [ "pw_resource_install_marshal", "group__pw__resource.html#ga6000827e0dc8637b0538f75800c0f581", null ]
 ];
\ No newline at end of file
